from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="Metadata")


@_attrs_define
class Metadata:
    """
    Attributes:
        process_url_in_text (bool | Unset):  Default: False.
        process_attachment_url (bool | Unset):  Default: True.
        attachment_requested (int | Unset):  Default: 0.
    """

    process_url_in_text: bool | Unset = False
    process_attachment_url: bool | Unset = True
    attachment_requested: int | Unset = 0
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        process_url_in_text = self.process_url_in_text

        process_attachment_url = self.process_attachment_url

        attachment_requested = self.attachment_requested

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if process_url_in_text is not UNSET:
            field_dict["process_url_in_text"] = process_url_in_text
        if process_attachment_url is not UNSET:
            field_dict["process_attachment_url"] = process_attachment_url
        if attachment_requested is not UNSET:
            field_dict["attachment_requested"] = attachment_requested

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        process_url_in_text = d.pop("process_url_in_text", UNSET)

        process_attachment_url = d.pop("process_attachment_url", UNSET)

        attachment_requested = d.pop("attachment_requested", UNSET)

        metadata = cls(
            process_url_in_text=process_url_in_text,
            process_attachment_url=process_attachment_url,
            attachment_requested=attachment_requested,
        )

        metadata.additional_properties = d
        return metadata

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
