from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="StaticFileChunkingStrategyParam")


@_attrs_define
class StaticFileChunkingStrategyParam:
    """
    Attributes:
        chunk_overlap_tokens (int):
        max_chunk_size_tokens (int):
    """

    chunk_overlap_tokens: int
    max_chunk_size_tokens: int
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        chunk_overlap_tokens = self.chunk_overlap_tokens

        max_chunk_size_tokens = self.max_chunk_size_tokens

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "chunk_overlap_tokens": chunk_overlap_tokens,
                "max_chunk_size_tokens": max_chunk_size_tokens,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        chunk_overlap_tokens = d.pop("chunk_overlap_tokens")

        max_chunk_size_tokens = d.pop("max_chunk_size_tokens")

        static_file_chunking_strategy_param = cls(
            chunk_overlap_tokens=chunk_overlap_tokens,
            max_chunk_size_tokens=max_chunk_size_tokens,
        )

        static_file_chunking_strategy_param.additional_properties = d
        return static_file_chunking_strategy_param

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
