from enum import Enum


class ListActionToolsV1ActionsToolsGetLlmType(str, Enum):
    CLAUDE = "claude"
    GEMINI = "gemini"
    GROK = "grok"
    OPENAI_ASSISTANT = "openai_assistant"
    OPENAI_CHAT = "openai_chat"
    OPENAI_RESPONSES = "openai_responses"
    VALUE_0 = ""

    def __str__(self) -> str:
        return str(self.value)
