from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="UsageInputTokensDetails")


@_attrs_define
class UsageInputTokensDetails:
    """The input tokens detailed information for the image generation.

    Attributes:
        image_tokens (int):
        text_tokens (int):
    """

    image_tokens: int
    text_tokens: int
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        image_tokens = self.image_tokens

        text_tokens = self.text_tokens

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "image_tokens": image_tokens,
                "text_tokens": text_tokens,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        image_tokens = d.pop("image_tokens")

        text_tokens = d.pop("text_tokens")

        usage_input_tokens_details = cls(
            image_tokens=image_tokens,
            text_tokens=text_tokens,
        )

        usage_input_tokens_details.additional_properties = d
        return usage_input_tokens_details

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
