from enum import Enum


class TimeRange(str, Enum):
    CUSTOM = "custom"
    LAST_30_DAYS = "last_30_days"
    LAST_7_DAYS = "last_7_days"
    LAST_90_DAYS = "last_90_days"
    LAST_YEAR = "last_year"

    def __str__(self) -> str:
        return str(self.value)
