from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="UserAttributes")


@_attrs_define
class UserAttributes:
    """
    Attributes:
        email (str | Unset):
        phone (str | Unset):
        password (str | Unset):
        data (Any | Unset):
        nonce (str | Unset):
    """

    email: str | Unset = UNSET
    phone: str | Unset = UNSET
    password: str | Unset = UNSET
    data: Any | Unset = UNSET
    nonce: str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        email = self.email

        phone = self.phone

        password = self.password

        data = self.data

        nonce = self.nonce

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if email is not UNSET:
            field_dict["email"] = email
        if phone is not UNSET:
            field_dict["phone"] = phone
        if password is not UNSET:
            field_dict["password"] = password
        if data is not UNSET:
            field_dict["data"] = data
        if nonce is not UNSET:
            field_dict["nonce"] = nonce

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        email = d.pop("email", UNSET)

        phone = d.pop("phone", UNSET)

        password = d.pop("password", UNSET)

        data = d.pop("data", UNSET)

        nonce = d.pop("nonce", UNSET)

        user_attributes = cls(
            email=email,
            phone=phone,
            password=password,
            data=data,
            nonce=nonce,
        )

        user_attributes.additional_properties = d
        return user_attributes

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
