from enum import Enum


class LastErrorCode(str, Enum):
    INVALID_FILE = "invalid_file"
    SERVER_ERROR = "server_error"
    UNSUPPORTED_FILE = "unsupported_file"

    def __str__(self) -> str:
        return str(self.value)
