from enum import Enum


class ImagesResponseSizeType0(str, Enum):
    VALUE_0 = "1024x1024"
    VALUE_1 = "1024x1536"
    VALUE_2 = "1536x1024"

    def __str__(self) -> str:
        return str(self.value)
