from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="Image")


@_attrs_define
class Image:
    """Represents the content or the URL of an image generated by the OpenAI API.

    Attributes:
        b64_json (None | str | Unset):
        revised_prompt (None | str | Unset):
        url (None | str | Unset):
    """

    b64_json: None | str | Unset = UNSET
    revised_prompt: None | str | Unset = UNSET
    url: None | str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        b64_json: None | str | Unset
        if isinstance(self.b64_json, Unset):
            b64_json = UNSET
        else:
            b64_json = self.b64_json

        revised_prompt: None | str | Unset
        if isinstance(self.revised_prompt, Unset):
            revised_prompt = UNSET
        else:
            revised_prompt = self.revised_prompt

        url: None | str | Unset
        if isinstance(self.url, Unset):
            url = UNSET
        else:
            url = self.url

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if b64_json is not UNSET:
            field_dict["b64_json"] = b64_json
        if revised_prompt is not UNSET:
            field_dict["revised_prompt"] = revised_prompt
        if url is not UNSET:
            field_dict["url"] = url

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)

        def _parse_b64_json(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        b64_json = _parse_b64_json(d.pop("b64_json", UNSET))

        def _parse_revised_prompt(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        revised_prompt = _parse_revised_prompt(d.pop("revised_prompt", UNSET))

        def _parse_url(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        url = _parse_url(d.pop("url", UNSET))

        image = cls(
            b64_json=b64_json,
            revised_prompt=revised_prompt,
            url=url,
        )

        image.additional_properties = d
        return image

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
