from enum import Enum


class MetricType(str, Enum):
    ACTIVE_WORKFLOWS = "active_workflows"
    ADDITIONAL_REVENUE = "additional_revenue"
    DOLLARS_SAVED = "dollars_saved"
    ROI_PERCENTAGE = "roi_percentage"
    SCHEDULED_JOBS = "scheduled_jobs"
    TIME_SAVED = "time_saved"
    TOTAL_AGENTS = "total_agents"
    TOTAL_WORKFLOW_RUNS = "total_workflow_runs"

    def __str__(self) -> str:
        return str(self.value)
