from enum import Enum


class PartitionParametersParamsHiResModelNameType0(str, Enum):
    CHIPPER = "chipper"
    DETECTRON2_ONNX = "detectron2_onnx"
    YOLOX = "yolox"
    YOLOX_QUANTIZED = "yolox_quantized"

    def __str__(self) -> str:
        return str(self.value)
