from enum import Enum


class ListIngestedFilesProxyV1IngestionFilesGetScopeType0(str, Enum):
    ALL = "all"
    KB = "kb"
    PERSONAL = "personal"

    def __str__(self) -> str:
        return str(self.value)
