from enum import Enum


class KnowledgeBaseRole(str, Enum):
    ADMIN = "admin"
    READ = "read"
    READ_WRITE = "read_write"
    READ_WRITE_UPDATE = "read_write_update"

    def __str__(self) -> str:
        return str(self.value)
