from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="WebSearchOptionsUserLocationApproximate")


@_attrs_define
class WebSearchOptionsUserLocationApproximate:
    """Approximate location parameters for the search.

    Attributes:
        city (str | Unset):
        country (str | Unset):
        region (str | Unset):
        timezone (str | Unset):
    """

    city: str | Unset = UNSET
    country: str | Unset = UNSET
    region: str | Unset = UNSET
    timezone: str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        city = self.city

        country = self.country

        region = self.region

        timezone = self.timezone

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if city is not UNSET:
            field_dict["city"] = city
        if country is not UNSET:
            field_dict["country"] = country
        if region is not UNSET:
            field_dict["region"] = region
        if timezone is not UNSET:
            field_dict["timezone"] = timezone

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        city = d.pop("city", UNSET)

        country = d.pop("country", UNSET)

        region = d.pop("region", UNSET)

        timezone = d.pop("timezone", UNSET)

        web_search_options_user_location_approximate = cls(
            city=city,
            country=country,
            region=region,
            timezone=timezone,
        )

        web_search_options_user_location_approximate.additional_properties = d
        return web_search_options_user_location_approximate

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
