from enum import Enum


class AppTypes(str, Enum):
    ADP = "adp"
    AIRTABLE = "airtable"
    ANON = "anon"
    ASANA = "asana"
    ASSEMBLYAI = "assemblyai"
    AWS = "aws"
    BOX = "box"
    CARTESIA = "cartesia"
    CHARGEBEE = "chargebee"
    CLAUDE = "claude"
    DATABRICKS = "databricks"
    DATADOG = "datadog"
    DATEV = "datev"
    DEEPGRAM = "deepgram"
    DEEPSEEK = "deepseek"
    DROPBOX = "dropbox"
    EXA = "exa"
    FIRECRAWL = "firecrawl"
    FLYIO = "flyio"
    GAMMA_AI = "gamma_ai"
    GEMINI = "gemini"
    GITHUB = "github"
    GOOGLE = "google"
    GOOGLE_ADS = "google_ads"
    GOOGLE_SERP = "google_serp"
    GRAFANA = "grafana"
    GROK = "grok"
    HUBSPOT = "hubspot"
    ICIMS = "icims"
    INTUIT = "intuit"
    JIRA = "jira"
    LOOKER = "looker"
    META = "meta"
    MUSO = "muso"
    NETSUITE = "netsuite"
    NORTHFLANK = "northflank"
    NOTION = "notion"
    OPENAI = "openai"
    OPUS = "opus"
    ORDWAY = "ordway"
    OUTLOOK = "outlook"
    PLAID = "plaid"
    REMOTION = "remotion"
    REPLICATE_FLUX = "replicate_flux"
    SALESFORCE = "salesforce"
    SAP = "sap"
    SIGMA_COMPUTING = "sigma_computing"
    SLACK = "slack"
    SLACK_USER = "slack_user"
    SNOWFLAKE = "snowflake"
    SPOTIFY = "spotify"
    STRIPE = "stripe"
    SUPERSET = "superset"
    THESYS = "thesys"
    TIPALTI = "tipalti"
    UKG = "ukg"
    UNSTRUCTUREDIO = "unstructuredio"
    VERCEL = "vercel"
    WHATSAPP = "whatsapp"
    WORKDAY = "workday"
    ZENDESK = "zendesk"
    ZOHO = "zoho"
    ZOOM = "zoom"

    def __str__(self) -> str:
        return str(self.value)
