from enum import Enum


class Region(str, Enum):
    ARABIA = "Arabia"
    ARABIA_EN = "Arabia_en"
    ARGENTINA = "Argentina"
    AUSTRALIA = "Australia"
    AUSTRIA = "Austria"
    BELGIUM_FR = "Belgium_fr"
    BELGIUM_NL = "Belgium_nl"
    BRAZIL = "Brazil"
    BULGARIA = "Bulgaria"
    CANADA_EN = "Canada_en"
    CANADA_FR = "Canada_fr"
    CATALAN = "Catalan"
    CHILE = "Chile"
    CHINA = "China"
    COLOMBIA = "Colombia"
    CROATIA = "Croatia"
    CZECH_REPUBLIC = "Czech_Republic"
    DENMARK = "Denmark"
    ESTONIA = "Estonia"
    FINLAND = "Finland"
    FRANCE = "France"
    GERMANY = "Germany"
    GREECE = "Greece"
    HONG_KONG = "Hong_Kong"
    HUNGARY = "Hungary"
    INDIA = "India"
    INDONESIA = "Indonesia"
    INDONESIA_EN = "Indonesia_en"
    IRELAND = "Ireland"
    ISRAEL = "Israel"
    ITALY = "Italy"
    JAPAN = "Japan"
    KOREA = "Korea"
    LATIN_AMERICA = "Latin_America"
    LATVIA = "Latvia"
    LITHUANIA = "Lithuania"
    MALAYSIA = "Malaysia"
    MALAYSIA_EN = "Malaysia_en"
    MEXICO = "Mexico"
    NETHERLANDS = "Netherlands"
    NEW_ZEALAND = "New_Zealand"
    NORWAY = "Norway"
    NO_REGION = "No_Region"
    PERU = "Peru"
    PHILIPPINES_EN = "Philippines_en"
    PHILIPPINES_TL = "Philippines_tl"
    POLAND = "Poland"
    PORTUGAL = "Portugal"
    ROMANIA = "Romania"
    RUSSIA = "Russia"
    SINGAPORE_EN = "Singapore_en"
    SLOVAK_REPUBLIC = "Slovak_Republic"
    SLOVENIA = "Slovenia"
    SOUTH_AFRICA = "South_Africa"
    SPAIN = "Spain"
    SWEDEN_SV = "Sweden_sv"
    SWITZERLAND_DE = "Switzerland_de"
    SWITZERLAND_FR = "Switzerland_fr"
    SWITZERLAND_IT = "Switzerland_it"
    TAIWAN = "Taiwan"
    THAILAND = "Thailand"
    TURKEY = "Turkey"
    UKRAINE = "Ukraine"
    UNITED_KINGDOM_EN = "United_Kingdom_en"
    UNITED_STATES_EN = "United_States_en"
    UNITED_STATES_ES = "United_States_es"
    VENEZUELA = "Venezuela"
    VIETNAM_VI = "Vietnam_vi"

    def __str__(self) -> str:
        return str(self.value)
