from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.knowledge_base_role import KnowledgeBaseRole

T = TypeVar("T", bound="KnowledgeBaseMembersBulkRequest")


@_attrs_define
class KnowledgeBaseMembersBulkRequest:
    """
    Attributes:
        emails (list[str]): List of emails to add.
        role (KnowledgeBaseRole): Role within a knowledge base / workspace.
    """

    emails: list[str]
    role: KnowledgeBaseRole
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        emails = self.emails

        role = self.role.value

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "emails": emails,
                "role": role,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        emails = cast(list[str], d.pop("emails"))

        role = KnowledgeBaseRole(d.pop("role"))

        knowledge_base_members_bulk_request = cls(
            emails=emails,
            role=role,
        )

        knowledge_base_members_bulk_request.additional_properties = d
        return knowledge_base_members_bulk_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
