from enum import Enum


class LlmChatOpenaiConfigModelType1(str, Enum):
    COMPUTER_USE_PREVIEW = "computer-use-preview"
    DEEPSEEK_R1 = "deepseek-r1"
    GPT_4O = "gpt-4o"
    GPT_4O_0513 = "gpt-4o-0513"
    GPT_4O_0806 = "gpt-4o-0806"
    GPT_4O_1120 = "gpt-4o-1120"
    GPT_4O_MINI = "gpt-4o-mini"
    GPT_4_1 = "gpt-4.1"
    GPT_4_1_MINI = "gpt-4.1-mini"
    GPT_4_1_NANO = "gpt-4.1-nano"
    GPT_4_32K = "gpt-4-32k"
    MODEL_ROUTER = "model-router"
    O1 = "o1"
    O1_MINI = "o1-mini"
    O3 = "o3"
    O3_MINI = "o3-mini"
    O3_PRO = "o3-pro"
    O4_MINI = "o4-mini"

    def __str__(self) -> str:
        return str(self.value)
