from enum import Enum


class ListIngestedFilesProxyV1IngestionFilesGetSortBy(str, Enum):
    CREATED_AT = "created_at"
    ORIGINAL_FILENAME = "original_filename"
    STATUS = "status"
    UPDATED_AT = "updated_at"

    def __str__(self) -> str:
        return str(self.value)
