from enum import Enum


class PartitionParametersParamsStrategyType0(str, Enum):
    AUTO = "auto"
    FAST = "fast"
    HI_RES = "hi_res"

    def __str__(self) -> str:
        return str(self.value)
