from enum import Enum


class ListVectorStoreFilesV1OpenaiStorageVectorStoreFilesListGetOrderType0(str, Enum):
    ASC = "asc"
    DESC = "desc"

    def __str__(self) -> str:
        return str(self.value)
